%global module_name ibus_cangjie

Name:             ibus-cangjie
Summary:          IBus engine to input Cangjie and Quick
Version:          2.5.0
Group:            System/Internationalization
Release:          %mkrel 2
License:          GPL-3.0-or-later
URL:              https://cangjie.pages.freedesktop.org/projects/ibus-cangjie
Source0:          https://gitlab.freedesktop.org/cangjie/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
# Patches from upstream
Patch1:           0001-tests-no-coverage.patch

BuildArch:        noarch

BuildRequires:    meson
BuildRequires:    desktop-file-utils
BuildRequires:    pkgconfig(ibus-1.0)
BuildRequires:    intltool
BuildRequires:    python3-devel
BuildRequires:    typelib(IBus)

# For the unit tests
BuildRequires:    python3-cangjie >= 1.0
BuildRequires:    python3-gobject3
BuildRequires:    gsound
BuildRequires:    typelib(GSound)

# ovitters: pkgconfig(gobject-introspection-1.0) includes script to determine typelib() auto buildrequires
BuildRequires:    pkgconfig(gobject-introspection-1.0)

Requires:         python3-cangjie >= 1.0
Requires:         python3-gobject3

%description
IBus engine for users of the Cangjie and Quick input methods.

It is primarily intended to Hong Kong people who want to input Traditional
Chinese, as they are (by far) the majority of Cangjie and Quick users.

However, it should work for others as well (e.g to input Simplified Chinese).


%prep
%autosetup -p1


%build
%meson
%meson_build


%install
%meson_install

%find_lang %{name}


%check
export CANGJIE_DB=/usr/share/libcangjie/cangjie.db
%meson_test --suite unittest


%files -f %{name}.lang
%doc AUTHORS README.md
%license COPYING
%{_bindir}/ibus-setup-cangjie
%{python3_sitelib}/%{module_name}/
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/org.freedesktop.cangjie.ibus.Cangjie.gschema.xml
%{_datadir}/glib-2.0/schemas/org.freedesktop.cangjie.ibus.Quick.gschema.xml
%{_datadir}/ibus/component/*.xml
%{_metainfodir}/*.metainfo.xml
%{_datadir}/glib-2.0/schemas/org.cangjians.ibus.*.gschema.xml
%{_datadir}/icons/hicolor/*/intl/*
%{_libexecdir}/ibus-engine-cangjie


%changelog
* Mon Mar 10 2025 papoteur <papoteur> 2.5.0-2.mga10
+ Revision: 2162507
- rebuild for python 3.13

* Mon Dec 30 2024 daviddavid <daviddavid> 2.5.0-1.mga10
+ Revision: 2131634
- new version: 2.5.0
- switch to meson build system

* Wed Mar 06 2024 daviddavid <daviddavid> 2.4-12.mga10
+ Revision: 2047772
- backport some upstream fixes
- use autoreconf to get rid of pesk 'imp' module
+ papoteur <papoteur>
- rebuild for python 3.12

* Thu Mar 31 2022 umeabot <umeabot> 2.4-11.mga9
+ Revision: 1836426
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 2.4-10.mga9
+ Revision: 1787405
- rebuild for python-3.10

* Sat Jun 26 2021 tmb <tmb> 2.4-9.mga9
+ Revision: 1733554
- rebuild for python 3.9

* Sat Jun 26 2021 wally <wally> 2.4-8.mga9
+ Revision: 1732383
- Rebuild for python 3.9

* Mon Feb 24 2020 daviddavid <daviddavid> 2.4-7.mga8
+ Revision: 1549735
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Sep 21 2019 daviddavid <daviddavid> 2.4-6.mga8
+ Revision: 1444353
- rebuild for python3.8

* Fri Jan 11 2019 tmb <tmb> 2.4-5.mga7
+ Revision: 1355152
- rebuild for python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 2.4-4.mga7
+ Revision: 1278865
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 2.4-3.mga7
+ Revision: 1135226
- Rebuild for python 3.6

* Sun Sep 25 2016 daviddavid <daviddavid> 2.4-2.mga6
+ Revision: 1056057
- disable testsuite as it fails on BS and autobuild too
- do not use parallel build for testsuite
- use "%%configure2_5x --build=%%{_build}" macro as it is a noarch package

* Tue Apr 05 2016 yochenhsieh <yochenhsieh> 2.4-1.mga6
+ Revision: 998628
- version 2.4 release

* Sat Feb 20 2016 umeabot <umeabot> 2.1-7.mga6
+ Revision: 971082
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 tv <tv> 2.1-6.mga6
+ Revision: 889173
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 2.1-5.mga5
+ Revision: 750583
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1-4.mga5
+ Revision: 680410
- Mageia 5 Mass Rebuild
+ ovitters <ovitters>
- add gobject-introspection BR for typelib auto BR

* Sat May 31 2014 pterjan <pterjan> 2.1-3.mga5
+ Revision: 629677
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 2.1-2.mga5
+ Revision: 629534
- Rebuild for new Python

* Fri Mar 07 2014 joequant <joequant> 2.1-1.mga5
+ Revision: 600853
- add ibus gir
- add group name
- imported package ibus-cangjie

